"""Big Book Python Modules
By Al Sweigart al@inventwithpython.com

A module to install the dependencies for the projects in The Big Book of Small Python Projects."""

__version__ = '0.1.1'

import webbrowser
webbrowser.open('https://inventwithpython.com/bigbookpython/')